@@ -24,14 +24,6 @@ AnalogMeterWidget::AnalogMeterWidget(QWidget *parent) : VolumeMeterWidget(parent
 }
 
 void AnalogMeterWidget::draw(QPainter *painter){
-    if(background == NULL){
-        drawBackground();
-    }
-
-    painter->drawImage(QRect(-0.5 * w, -3.4 * h, w, h),
-                       *background,
-                       QRect(0, 0, w, h));
-
     painter->rotate(-25);
 
     if(dbUnit){
@@ -47,9 +39,35 @@ void AnalogMeterWidget::draw(QPainter *painter){
     painter->drawLine(0, 0, 0, -3.25 * h);
 }
 
-void AnalogMeterWidget::drawBackground(){
-    initBackground();
+void AnalogMeterWidget::drawBackground(QPainter *painter){
+    painter->drawImage(QRect(-0.5 * w, -3.4 * h, w, h),
+                       *background,
+                       QRect(0, 0, w, h));
+}
 
+void AnalogMeterWidget::drawTriggerIndicator(QPainter *painter){
+    painter->rotate(-25);
+    if(dbUnit){
+        painter->rotate(50. / ((float) MAX_DB) * triggerValue);
+    }else{
+        painter->rotate(50. / ((float) MAX_LINEAR) * triggerValue);
+    }
+
+    QPen pen(triggerIndicatorColor);
+    pen.setWidth(2 * h / 100.);
+    painter->setPen(pen);
+
+    painter->drawLine(0, 0, 0, -3.15 * h);
+
+    if(dbUnit){
+        painter->rotate(-50. / ((float) MAX_DB) * triggerValue);
+    }else{
+        painter->rotate(-50. / ((float) MAX_LINEAR) * triggerValue);
+    }
+    painter->rotate(25);
+}
+
+void AnalogMeterWidget::prepareBackground(){
     QPainter painter(background);
     initPainter(&painter);
 
