@@ -32,21 +32,27 @@ void HorizontalVolumeBarWidget::draw(QPainter *painter){
         vol = ((float) currentValue) / MAX_LINEAR;
     }
 
-    if(background == NULL){
-        drawBackground();
-    }
-
-    painter->drawImage(QRect(0, 0, w, h),
-                       *background,
-                       QRect(0, 0, w, h));
-
     QRectF scale(0.02 * h, 0.02 * h, 2.94 * h * vol, 0.7 * h);
     painter->fillRect(scale, QBrush(Qt::darkBlue));
 }
 
-void HorizontalVolumeBarWidget::drawBackground(){
-    initBackground();
+void HorizontalVolumeBarWidget::drawTriggerIndicator(QPainter *painter){
+    float vol;
 
+    if(dbUnit){
+        vol = ((float) triggerValue) / MAX_DB;
+    }else{
+        vol = ((float) triggerValue) / MAX_LINEAR;
+    }
+
+    QPen pen(triggerIndicatorColor);
+    pen.setWidth(2 * h / 100.);
+    painter->setPen(pen);
+
+    painter->drawLine(2.94 * h * vol, 0.03 * h, 2.94 * h * vol, 0.71 * h);
+}
+
+void HorizontalVolumeBarWidget::prepareBackground(){
     QPainter painter(background);
     initPainter(&painter);
 
