@@ -20,6 +20,7 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+#include <QProcess>
 #include <QMainWindow>
 #include <QStringList>
 
@@ -47,11 +48,18 @@ private:
 
     int maxVol;
     int meter;
+    QProcess *process;
     QStringList *sources;
+    int triggerValue;
+    QString triggerCommand;
     VolumeMeterWidget *volumeMeterWidget;
 
+    void getSettings();
+
 private slots:
+    void processFinished();
     void resetMaxValue();
+    void settingsDialog();
     void setLinearScale();
     void setDbScale();
     void sourceChanged(int source);
