@@ -37,6 +37,7 @@ public:
 
     virtual void updateValue(int value);
     virtual void setDbUnit(bool b);
+    virtual void setTriggerValue(int value);
 
 signals:
     void clicked();
@@ -46,14 +47,22 @@ protected:
     int currentValue;
     bool dbUnit;
     float h;
+    Qt::GlobalColor triggerIndicatorColor;
+    int triggerValue;
     float w;
 
     virtual void calculateSize();
+
     virtual void draw(QPainter *painter) = 0;
+    virtual void drawBackground(QPainter *painter);
+    virtual void drawTriggerIndicator(QPainter *painter);
+
     virtual void initBackground();
     virtual void initPainter(QPainter *painter);
     void mouseReleaseEvent(QMouseEvent *);
     virtual void paintEvent(QPaintEvent *event);
+
+    virtual void prepareBackground();
     virtual void resizeEvent(QResizeEvent *event);
 };
 
